@@ -8,7 +8,7 @@ Perl::Dist::WiX::Installer - WiX-specific routines.
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::Installer version 0.185.
+This document describes Perl::Dist::WiX::Installer version 0.190.
 
 =head1 DESCRIPTION
 
@@ -43,7 +43,7 @@ require Perl::Dist::WiX::Icons;
 require Perl::Dist::WiX::CreateFolder;
 require Perl::Dist::WiX::RemoveFolder;
 
-use version; $VERSION = version->new('0.185')->numify;
+use version; $VERSION = version->new('0.190')->numify;
 #>>>
 
 =head2 Accessors
@@ -228,7 +228,9 @@ sub new {
 	$self->{directories} = Perl::Dist::WiX::DirectoryTree->new(
 		app_dir  => $self->image_dir,
 		app_name => $self->app_name,
-	)->initialize_tree( @{ $self->{msi_directory_tree_additions} } );
+	  )
+	  ->initialize_tree( $self->perl_version,
+		@{ $self->{msi_directory_tree_additions} } );
 	$self->{fragments} = {};
 	$self->{fragments}->{Icons} =
 	  Perl::Dist::WiX::StartMenu->new( directory => 'D_App_Menu', );
@@ -242,6 +244,10 @@ sub new {
 		directory => 'Cpan',
 		id        => 'CPANFolder',
 	);
+	$self->{fragments}->{CreateCpan} = Perl::Dist::WiX::CreateFolder->new(
+		directory => 'Cpanplus',
+		id        => 'CPANPLUSFolder',
+	) if ( '5100' eq $self->perl_version );
 
 	$self->{icons} = Perl::Dist::WiX::Icons->new( trace => $self->{trace} );
 
@@ -572,7 +578,7 @@ sub write_msi {
 		}
 
 		push @files, $filename_out;
-	} ## end foreach my $key ( keys %{ $self...
+	} ## end foreach my $key ( keys %{ $self...})
 
 	# Generate feature tree.
 	$self->{feature_tree_obj} =
